# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class RouteMeterChannelLatestReadingResponse(Model):
    """RouteMeterChannelLatestReadingResponse.

    :param meters: List of meters with channels and their latest reading
    :type meters:
     list[~energycap.sdk.models.MeterChildIncludePlaceChannelLatestReading]
    :param route_id: The route identifier
    :type route_id: int
    :param route_info: The route info
    :type route_info: str
    :param route_code: The route code
    :type route_code: str
    """

    _attribute_map = {
        'meters': {'key': 'meters', 'type': '[MeterChildIncludePlaceChannelLatestReading]'},
        'route_id': {'key': 'routeId', 'type': 'int'},
        'route_info': {'key': 'routeInfo', 'type': 'str'},
        'route_code': {'key': 'routeCode', 'type': 'str'},
    }

    def __init__(self, meters=None, route_id=None, route_info=None, route_code=None):
        super(RouteMeterChannelLatestReadingResponse, self).__init__()
        self.meters = meters
        self.route_id = route_id
        self.route_info = route_info
        self.route_code = route_code
