# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class CommodityMismatchChild(Model):
    """CommodityMismatchChild.

    :param commodity:
    :type commodity: ~energycap.sdk.models.CommodityChild
    :param count:
    :type count: int
    """

    _attribute_map = {
        'commodity': {'key': 'commodity', 'type': 'CommodityChild'},
        'count': {'key': 'count', 'type': 'int'},
    }

    def __init__(self, commodity=None, count=None):
        super(CommodityMismatchChild, self).__init__()
        self.commodity = commodity
        self.count = count
