# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class MoveBillsDestination(Model):
    """MoveBillsDestination.

    :param commodities:  <span class='property-internal'>Required
     (defined)</span>
    :type commodities: list[~energycap.sdk.models.CommodityChild]
    :param accounts:  <span class='property-internal'>Required
     (defined)</span>
    :type accounts: list[~energycap.sdk.models.DestinationAccountResponse]
    """

    _attribute_map = {
        'commodities': {'key': 'commodities', 'type': '[CommodityChild]'},
        'accounts': {'key': 'accounts', 'type': '[DestinationAccountResponse]'},
    }

    def __init__(self, commodities=None, accounts=None):
        super(MoveBillsDestination, self).__init__()
        self.commodities = commodities
        self.accounts = accounts
