# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class GeneralLedgerChild(Model):
    """GeneralLedgerChild.

    :param general_ledger_id:
    :type general_ledger_id: int
    :param general_ledger_code:
    :type general_ledger_code: str
    :param general_ledger_info:
    :type general_ledger_info: str
    """

    _attribute_map = {
        'general_ledger_id': {'key': 'generalLedgerId', 'type': 'int'},
        'general_ledger_code': {'key': 'generalLedgerCode', 'type': 'str'},
        'general_ledger_info': {'key': 'generalLedgerInfo', 'type': 'str'},
    }

    def __init__(self, general_ledger_id=None, general_ledger_code=None, general_ledger_info=None):
        super(GeneralLedgerChild, self).__init__()
        self.general_ledger_id = general_ledger_id
        self.general_ledger_code = general_ledger_code
        self.general_ledger_info = general_ledger_info
