# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class EnergyStarRatingChild(Model):
    """EnergyStarRatingChild.

    :param rating_date:
    :type rating_date: datetime
    :param rating:
    :type rating: int
    """

    _attribute_map = {
        'rating_date': {'key': 'ratingDate', 'type': 'iso-8601'},
        'rating': {'key': 'rating', 'type': 'int'},
    }

    def __init__(self, rating_date=None, rating=None):
        super(EnergyStarRatingChild, self).__init__()
        self.rating_date = rating_date
        self.rating = rating
