# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGMonthlyResponseGHGType(Model):
    """PlaceDigestGHGMonthlyResponseGHGType.

    :param ghg_type_id: GHG type identifier
    :type ghg_type_id: int
    :param ghg_type_code: GHG type code
    :type ghg_type_code: str
    :param ghg_type_info: GHG type info
    :type ghg_type_info: str
    :param target_comparison:
    :type target_comparison:
     ~energycap.sdk.models.PlaceDigestGHGMonthlyResponseTargetComparison
    :param results: An array of monthly data
    :type results:
     list[~energycap.sdk.models.PlaceDigestGHGMonthlyResponseResults]
    """

    _attribute_map = {
        'ghg_type_id': {'key': 'ghgTypeId', 'type': 'int'},
        'ghg_type_code': {'key': 'ghgTypeCode', 'type': 'str'},
        'ghg_type_info': {'key': 'ghgTypeInfo', 'type': 'str'},
        'target_comparison': {'key': 'targetComparison', 'type': 'PlaceDigestGHGMonthlyResponseTargetComparison'},
        'results': {'key': 'results', 'type': '[PlaceDigestGHGMonthlyResponseResults]'},
    }

    def __init__(self, ghg_type_id=None, ghg_type_code=None, ghg_type_info=None, target_comparison=None, results=None):
        super(PlaceDigestGHGMonthlyResponseGHGType, self).__init__()
        self.ghg_type_id = ghg_type_id
        self.ghg_type_code = ghg_type_code
        self.ghg_type_info = ghg_type_info
        self.target_comparison = target_comparison
        self.results = results
