# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OkResult(Model):
    """OkResult.

    Variables are only populated by the server, and will be ignored when
    sending a request.

    :ivar status_code:
    :vartype status_code: int
    """

    _validation = {
        'status_code': {'readonly': True},
    }

    _attribute_map = {
        'status_code': {'key': 'statusCode', 'type': 'int'},
    }

    def __init__(self):
        super(OkResult, self).__init__()
        self.status_code = None
