# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PostalCodeResponse(Model):
    """PostalCodeResponse.

    :param postal_code: The postal code
    :type postal_code: str
    :param city: The city of the postal code
    :type city: str
    :param state: The state of the postal code
    :type state: str
    :param country: The country of the postal code
    :type country: str
    :param weather_station:
    :type weather_station:
     ~energycap.sdk.models.PostalCodeResponseWeatherStation
    """

    _attribute_map = {
        'postal_code': {'key': 'postalCode', 'type': 'str'},
        'city': {'key': 'city', 'type': 'str'},
        'state': {'key': 'state', 'type': 'str'},
        'country': {'key': 'country', 'type': 'str'},
        'weather_station': {'key': 'weatherStation', 'type': 'PostalCodeResponseWeatherStation'},
    }

    def __init__(self, postal_code=None, city=None, state=None, country=None, weather_station=None):
        super(PostalCodeResponse, self).__init__()
        self.postal_code = postal_code
        self.city = city
        self.state = state
        self.country = country
        self.weather_station = weather_station
