# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SearchPlaceChild(Model):
    """SearchPlaceChild.

    :param result:
    :type result: ~energycap.sdk.models.SearchPlaceChildSearchPlaceChild
    """

    _attribute_map = {
        'result': {'key': 'result', 'type': 'SearchPlaceChildSearchPlaceChild'},
    }

    def __init__(self, result=None):
        super(SearchPlaceChild, self).__init__()
        self.result = result
