# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class DeviceChannelChild(Model):
    """DeviceChannelChild.

    :param last_calibrated: The date and time the channel was last calibrated
    :type last_calibrated: datetime
    :param channel_number: The channel number
    :type channel_number: int
    :param channel_text: The channel text
    :type channel_text: str
    :param channel_flag: The channel flag
    :type channel_flag: bool
    :param channel_integer: The channel integer
    :type channel_integer: int
    :param channel_float: The channel float
    :type channel_float: float
    :param channel_char: The channel char
    :type channel_char: str
    :param read_direction: The channel's read direction
    :type read_direction: str
    :param read_method: The channel's read method
    :type read_method: str
    :param rf_ert_id:
    :type rf_ert_id: str
    :param rf_ert_type:
    :type rf_ert_type: int
    :param rf_frequency:
    :type rf_frequency: float
    :param rf_tone:
    :type rf_tone: float
    :param decode_type: The decode type of the channel
    :type decode_type: int
    """

    _attribute_map = {
        'last_calibrated': {'key': 'lastCalibrated', 'type': 'iso-8601'},
        'channel_number': {'key': 'channelNumber', 'type': 'int'},
        'channel_text': {'key': 'channelText', 'type': 'str'},
        'channel_flag': {'key': 'channelFlag', 'type': 'bool'},
        'channel_integer': {'key': 'channelInteger', 'type': 'int'},
        'channel_float': {'key': 'channelFloat', 'type': 'float'},
        'channel_char': {'key': 'channelChar', 'type': 'str'},
        'read_direction': {'key': 'readDirection', 'type': 'str'},
        'read_method': {'key': 'readMethod', 'type': 'str'},
        'rf_ert_id': {'key': 'rf_Ert_Id', 'type': 'str'},
        'rf_ert_type': {'key': 'rf_Ert_Type', 'type': 'int'},
        'rf_frequency': {'key': 'rf_Frequency', 'type': 'float'},
        'rf_tone': {'key': 'rf_Tone', 'type': 'float'},
        'decode_type': {'key': 'decodeType', 'type': 'int'},
    }

    def __init__(self, last_calibrated=None, channel_number=None, channel_text=None, channel_flag=None, channel_integer=None, channel_float=None, channel_char=None, read_direction=None, read_method=None, rf_ert_id=None, rf_ert_type=None, rf_frequency=None, rf_tone=None, decode_type=None):
        super(DeviceChannelChild, self).__init__()
        self.last_calibrated = last_calibrated
        self.channel_number = channel_number
        self.channel_text = channel_text
        self.channel_flag = channel_flag
        self.channel_integer = channel_integer
        self.channel_float = channel_float
        self.channel_char = channel_char
        self.read_direction = read_direction
        self.read_method = read_method
        self.rf_ert_id = rf_ert_id
        self.rf_ert_type = rf_ert_type
        self.rf_frequency = rf_frequency
        self.rf_tone = rf_tone
        self.decode_type = decode_type
