# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceCategoryResponse(Model):
    """PlaceCategoryResponse.

    :param place_group_category_id: The place category identifier
    :type place_group_category_id: int
    :param place_group_category_code: The place category code
    :type place_group_category_code: str
    :param place_group_category_info: The place category name
    :type place_group_category_info: str
    :param auto_group: Is this category an automatically maintained one?
    :type auto_group: bool
    :param number_of_groups: Number of groups within this category
    :type number_of_groups: int
    :param number_of_groups_with_visible_members: Number of groups within this
     category with members the logged in can see
    :type number_of_groups_with_visible_members: int
    """

    _attribute_map = {
        'place_group_category_id': {'key': 'placeGroupCategoryId', 'type': 'int'},
        'place_group_category_code': {'key': 'placeGroupCategoryCode', 'type': 'str'},
        'place_group_category_info': {'key': 'placeGroupCategoryInfo', 'type': 'str'},
        'auto_group': {'key': 'autoGroup', 'type': 'bool'},
        'number_of_groups': {'key': 'numberOfGroups', 'type': 'int'},
        'number_of_groups_with_visible_members': {'key': 'numberOfGroupsWithVisibleMembers', 'type': 'int'},
    }

    def __init__(self, place_group_category_id=None, place_group_category_code=None, place_group_category_info=None, auto_group=None, number_of_groups=None, number_of_groups_with_visible_members=None):
        super(PlaceCategoryResponse, self).__init__()
        self.place_group_category_id = place_group_category_id
        self.place_group_category_code = place_group_category_code
        self.place_group_category_info = place_group_category_info
        self.auto_group = auto_group
        self.number_of_groups = number_of_groups
        self.number_of_groups_with_visible_members = number_of_groups_with_visible_members
