# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class OtherSavingsCategory(Model):
    """OtherSavingsCategory.

    :param other_savings_category_id: Other savings category identifier
    :type other_savings_category_id: int
    :param other_savings_category_info: Other savings category name
    :type other_savings_category_info: str
    """

    _attribute_map = {
        'other_savings_category_id': {'key': 'otherSavingsCategoryId', 'type': 'int'},
        'other_savings_category_info': {'key': 'otherSavingsCategoryInfo', 'type': 'str'},
    }

    def __init__(self, other_savings_category_id=None, other_savings_category_info=None):
        super(OtherSavingsCategory, self).__init__()
        self.other_savings_category_id = other_savings_category_id
        self.other_savings_category_info = other_savings_category_info
