# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class SpecificWidgetResponse(Model):
    """SpecificWidgetResponse.

    :param specific_widget_id: Specific widget identifier
    :type specific_widget_id: int
    :param title: Widget title
    :type title: str
    :param widget_info: Widget title
    :type widget_info: str
    :param description: Widget description
    :type description: str
    :param row: Dashboard row
    :type row: int
    :param col: Dashboard column
    :type col: int
    :param height: Widget height
    :type height: int
    :param width: Widget width
    :type width: int
    :param filters: Widget filters
    :type filters: list[~energycap.sdk.models.FilterResponse]
    """

    _attribute_map = {
        'specific_widget_id': {'key': 'specificWidgetId', 'type': 'int'},
        'title': {'key': 'title', 'type': 'str'},
        'widget_info': {'key': 'widgetInfo', 'type': 'str'},
        'description': {'key': 'description', 'type': 'str'},
        'row': {'key': 'row', 'type': 'int'},
        'col': {'key': 'col', 'type': 'int'},
        'height': {'key': 'height', 'type': 'int'},
        'width': {'key': 'width', 'type': 'int'},
        'filters': {'key': 'filters', 'type': '[FilterResponse]'},
    }

    def __init__(self, specific_widget_id=None, title=None, widget_info=None, description=None, row=None, col=None, height=None, width=None, filters=None):
        super(SpecificWidgetResponse, self).__init__()
        self.specific_widget_id = specific_widget_id
        self.title = title
        self.widget_info = widget_info
        self.description = description
        self.row = row
        self.col = col
        self.height = height
        self.width = width
        self.filters = filters
