# coding=utf-8
# --------------------------------------------------------------------------
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.
# --------------------------------------------------------------------------

from msrest.serialization import Model


class PlaceDigestGHGYearlyResponse(Model):
    """PlaceDigestGHGYearlyResponse.

    :param place_code: The place code
    :type place_code: str
    :param place_info: The place info
    :type place_info: str
    :param place_id: The place identifier
    :type place_id: int
    :param updated: The date and time the data was updated
    :type updated: datetime
    :param equivalent_co2_emissions_unit:
    :type equivalent_co2_emissions_unit: ~energycap.sdk.models.UnitChild
    :param ghg_types: List of greenhouse gas types with use by year
    :type ghg_types:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseGHGType]
    :param ghg_scopes: List of greenhouse gas scopes by type with use by year
    :type ghg_scopes:
     list[~energycap.sdk.models.PlaceDigestGHGYearlyResponseGHGScope]
    """

    _attribute_map = {
        'place_code': {'key': 'placeCode', 'type': 'str'},
        'place_info': {'key': 'placeInfo', 'type': 'str'},
        'place_id': {'key': 'placeId', 'type': 'int'},
        'updated': {'key': 'updated', 'type': 'iso-8601'},
        'equivalent_co2_emissions_unit': {'key': 'equivalentCO2EmissionsUnit', 'type': 'UnitChild'},
        'ghg_types': {'key': 'ghgTypes', 'type': '[PlaceDigestGHGYearlyResponseGHGType]'},
        'ghg_scopes': {'key': 'ghgScopes', 'type': '[PlaceDigestGHGYearlyResponseGHGScope]'},
    }

    def __init__(self, place_code=None, place_info=None, place_id=None, updated=None, equivalent_co2_emissions_unit=None, ghg_types=None, ghg_scopes=None):
        super(PlaceDigestGHGYearlyResponse, self).__init__()
        self.place_code = place_code
        self.place_info = place_info
        self.place_id = place_id
        self.updated = updated
        self.equivalent_co2_emissions_unit = equivalent_co2_emissions_unit
        self.ghg_types = ghg_types
        self.ghg_scopes = ghg_scopes
